==> flutter_catalogue_widgets-0.0.6.tar.gz: lib/custom-bottomnavbar.dart <==
/*
Description:
The bottom nav bar is used for navigation. It contains icons and texts at the bottom of the screen which can be used to navigate from one place to another4

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-bottomnavbar.dart';

Usage:
-Creating the object for the Bottom Navigation Bar

    List<BottomNavigationBarItem> bottomnavitems = [];

    BottomNavigationBarItem bottomnavitem1= new BottomNavigationBarItem(
      icon: Icon(Icons.home),title: Text('Home',style: TextStyle(fontSize: 12)),);
    BottomNavigationBarItem bottomnavitem2= new BottomNavigationBarItem(
      icon: Icon(Icons.phone),title: Text('Phone',style: TextStyle(fontSize: 12)),);
    BottomNavigationBarItem bottomnavitem3= new BottomNavigationBarItem(
      icon: Icon(Icons.map),title: Text('Map',style: TextStyle(fontSize: 12),),);
    bottomnavitems.add(bottomnavitem1);
    bottomnavitems.add(bottomnavitem2);
    bottomnavitems.add(bottomnavitem3);

        BottomNavBarParameters param = new BottomNavBarParameters(items: bottomnavitems,
        selectedItemColor: Colors.red,
        backgroundColor: Colors.black,
        unselectedItemColor: Colors.grey,
        showUnselectedLabels: true,
        showSelectedLabels: true,
        selectedIconTheme: IconThemeData(color: Colors.red));

-Object call for the widget
   bottomNavigationBar: BottomNavBar(param)

    Author:
    Karan Arora
*/

import 'package:flutter/material.dart';
import 'theme.dart';
import 'widget-classesUsed.dart';
import 'consts.dart' as cons;

class BottomNavBar extends StatefulWidget {
  BottomNavBarParameters param;
  BottomNavBar(this.param);

  @override
  _MyStatefulWidgetState createState() => _MyStatefulWidgetState(this.param);
}

class _MyStatefulWidgetState extends State<BottomNavBar> {
  BottomNavBarParameters param;
  _MyStatefulWidgetState(this.param);
  int _selectedIndex = 0;
  void _onItemTapped(int index) {
    setState(() {
      _selectedIndex = index;
      print(index);
    });
  }

  @override
  Widget build(BuildContext context) {
      if (param == null) {
        return BottomNavigationBar(
          elevation: cons.elevationFive,
          iconSize: cons.icon_size1,
          selectedFontSize: cons.selectedFontSize,
          unselectedFontSize: cons.unselectedFontSize,
          showSelectedLabels: cons.showselectedlabels,
          //fixedColor: MediumGreyThemeData().bottomAppBarColor,
          onTap: _onItemTapped,
          backgroundColor: Theme.of(context).backgroundColor,
          unselectedIconTheme: Theme.of(context).primaryIconTheme,
          selectedItemColor: Theme.of(context).selectedRowColor,
          unselectedItemColor: Theme.of(context).unselectedWidgetColor,
          currentIndex: _selectedIndex,
          showUnselectedLabels: cons.showUnselectedLabels,
          items: cons.item,
          unselectedLabelStyle: null,
          selectedIconTheme: Theme.of(context).iconTheme,
          selectedLabelStyle: null,
        );
      }
      else {
        return BottomNavigationBar(
          elevation: (param.elevation != null) ? param.elevation : cons
              .elevation,
          iconSize: (param.iconSize != null) ? param.iconSize : cons.icon_size1,
          selectedFontSize: (param.selectedFontSize != null) ? param
              .selectedFontSize : cons.selectedFontSize,
          unselectedFontSize: (param.unselectedFontSize != null) ? param
              .unselectedFontSize : cons.unselectedFontSize,
          showSelectedLabels: (param.showSelectedLabels != null) ? param
              .showSelectedLabels : cons.showselectedlabels,
/*          fixedColor: (param.fixedColor != null)
              ? param.fixedColor
              : MediumGreyThemeData().bottomAppBarColor,*/
          onTap: _onItemTapped,
          currentIndex: _selectedIndex,
          backgroundColor: (param.backgroundColor != null) ? param
              .backgroundColor : Theme.of(context).backgroundColor,
          unselectedIconTheme: (param.unselectedIconTheme != null) ? param
              .unselectedIconTheme : Theme.of(context).primaryIconTheme,
          selectedItemColor: (param.selectedItemColor != null) ? param.selectedItemColor : Theme.of(context).backgroundColor,
          unselectedItemColor: (param.unselectedItemColor != null) ? param
              .unselectedItemColor : Theme.of(context)
              .unselectedWidgetColor,
          showUnselectedLabels: (param.showUnselectedLabels) ? param
              .showUnselectedLabels : cons.showUnselectedLabels,
          items: (param.items != null) ? param.items : cons.item,
          selectedLabelStyle: (param.selectedLabelStyle != null) ? param
              .selectedLabelStyle : null,
          selectedIconTheme: (param.selectedIconTheme != null) ? param
              .selectedIconTheme : Theme.of(context).iconTheme,
          unselectedLabelStyle: (param.unselectedLabelStyle != null) ? param
              .unselectedLabelStyle : null,
        );
      }
    }
  }

==> flutter_catalogue_widgets-0.0.14.tar.gz: lib/custom-bottomnavbar.dart <==
/*
Description:
The bottom nav bar is used for navigation. It contains icons and texts at the bottom of the screen which can be used to navigate from one place to another4

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-bottomnavbar.dart';

Usage:
-Creating the object for the Bottom Navigation Bar

    List<BottomNavigationBarItem> bottomnavitems = [];

    BottomNavigationBarItem bottomnavitem1= new BottomNavigationBarItem(
      icon: Icon(Icons.home),title: Text('Home',style: TextStyle(fontSize: 12)),);
    BottomNavigationBarItem bottomnavitem2= new BottomNavigationBarItem(
      icon: Icon(Icons.phone),title: Text('Phone',style: TextStyle(fontSize: 12)),);
    BottomNavigationBarItem bottomnavitem3= new BottomNavigationBarItem(
      icon: Icon(Icons.map),title: Text('Map',style: TextStyle(fontSize: 12),),);
    bottomnavitems.add(bottomnavitem1);
    bottomnavitems.add(bottomnavitem2);
    bottomnavitems.add(bottomnavitem3);

        BottomNavBarParameters param = new BottomNavBarParameters(items: bottomnavitems,
        selectedItemColor: Colors.red,
        backgroundColor: Colors.black,
        unselectedItemColor: Colors.grey,
        showUnselectedLabels: true,
        showSelectedLabels: true,
        selectedIconTheme: IconThemeData(color: Colors.red));

-Object call for the widget
   bottomNavigationBar: BottomNavBar(param)

    Author:
    Karan Arora
*/

import 'package:flutter/material.dart';
import 'widget-classesUsed.dart';
import 'consts.dart' as cons;

class BottomNavBar extends StatefulWidget {
  final BottomNavBarParameters param;
  BottomNavBar(this.param);

  @override
  _MyStatefulWidgetState createState() => _MyStatefulWidgetState(this.param);
}

class _MyStatefulWidgetState extends State<BottomNavBar> {
  BottomNavBarParameters param;
  _MyStatefulWidgetState(this.param);
  int _selectedIndex = 0;
  void _onItemTapped(int index) {
    setState(() {
      _selectedIndex = index;
      print(index);
    });
  }

  @override
  Widget build(BuildContext context) {
      if (param == null) {
        return BottomNavigationBar(
          elevation: cons.elevationFive,
          iconSize: cons.icon_size1,
          selectedFontSize: cons.selectedFontSize,
          unselectedFontSize: cons.unselectedFontSize,
          showSelectedLabels: cons.showselectedlabels,
          //fixedColor: mediumGreyThemeData().bottomAppBarColor,
          onTap: _onItemTapped,
          backgroundColor: Theme.of(context).backgroundColor,
          unselectedIconTheme: Theme.of(context).primaryIconTheme,
          selectedItemColor: Theme.of(context).selectedRowColor,
          unselectedItemColor: Theme.of(context).unselectedWidgetColor,
          currentIndex: _selectedIndex,
          showUnselectedLabels: cons.showUnselectedLabels,
          items: cons.item,
          unselectedLabelStyle: null,
          selectedIconTheme: Theme.of(context).iconTheme,
          selectedLabelStyle: null,
        );
      }
      else {
        return BottomNavigationBar(
          elevation: (param.elevation != null) ? param.elevation : cons
              .elevation,
          iconSize: (param.iconSize != null) ? param.iconSize : cons.icon_size1,
          selectedFontSize: (param.selectedFontSize != null) ? param
              .selectedFontSize : cons.selectedFontSize,
          unselectedFontSize: (param.unselectedFontSize != null) ? param
              .unselectedFontSize : cons.unselectedFontSize,
          showSelectedLabels: (param.showSelectedLabels != null) ? param
              .showSelectedLabels : cons.showselectedlabels,
/*          fixedColor: (param.fixedColor != null)
              ? param.fixedColor
              : mediumGreyThemeData().bottomAppBarColor,*/
          onTap: _onItemTapped,
          currentIndex: _selectedIndex,
          backgroundColor: (param.backgroundColor != null) ? param
              .backgroundColor : Theme.of(context).backgroundColor,
          unselectedIconTheme: (param.unselectedIconTheme != null) ? param
              .unselectedIconTheme : Theme.of(context).primaryIconTheme,
          selectedItemColor: (param.selectedItemColor != null) ? param.selectedItemColor : Theme.of(context).backgroundColor,
          unselectedItemColor: (param.unselectedItemColor != null) ? param
              .unselectedItemColor : Theme.of(context)
              .unselectedWidgetColor,
          showUnselectedLabels: (param.showUnselectedLabels) ? param
              .showUnselectedLabels : cons.showUnselectedLabels,
          items: (param.items != null) ? param.items : cons.item,
          selectedLabelStyle: (param.selectedLabelStyle != null) ? param
              .selectedLabelStyle : null,
          selectedIconTheme: (param.selectedIconTheme != null) ? param
              .selectedIconTheme : Theme.of(context).iconTheme,
          unselectedLabelStyle: (param.unselectedLabelStyle != null) ? param
              .unselectedLabelStyle : null,
        );
      }
    }
  }
